pub struct ProviderPool { /* private fields */ }Expand description
Round-robin provider pool with per-provider circuit breakers.
Automatically skips unhealthy (circuit-open) providers and falls back to the next available one.
Implementations
Sourceimpl ProviderPool
impl ProviderPool
Sourcepub fn new(
transports: Vec<Arc<dyn RpcTransport>>,
config: ProviderPoolConfig,
) -> Self
pub fn new( transports: Vec<Arc<dyn RpcTransport>>, config: ProviderPoolConfig, ) -> Self
Build a pool from a list of transports.
Sourcepub fn new_with_metrics(
transports: Vec<Arc<dyn RpcTransport>>,
config: ProviderPoolConfig,
) -> Self
pub fn new_with_metrics( transports: Vec<Arc<dyn RpcTransport>>, config: ProviderPoolConfig, ) -> Self
Build a pool with per-provider metrics automatically created.
Sourcepub fn health_summary(&self) -> Vec<(String, HealthStatus, String)>
pub fn health_summary(&self) -> Vec<(String, HealthStatus, String)>
Returns summary of each provider’s health.
Sourcepub fn healthy_count(&self) -> usize
pub fn healthy_count(&self) -> usize
Number of providers whose circuit breaker allows requests.
Sourcepub fn metrics(&self) -> Vec<MetricsSnapshot>
pub fn metrics(&self) -> Vec<MetricsSnapshot>
Return metrics snapshots for all providers that have metrics enabled.
Sourcepub fn health_report(&self) -> Vec<Value>
pub fn health_report(&self) -> Vec<Value>
Detailed health report for each provider as JSON-serializable values.
When per-provider metrics are available the report includes
additional fields such as total_requests, success_rate, and
avg_latency_ms.